==> segment-wrapper-3.2.0.tgz: package/lib/adobeRepository.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import { getConfig } from './config.js';
var ADOBE_ORG_ID = '05FF6243578784B37F000101@AdobeOrg';
var AUTHENTICATE_STATE = 1;
var DEFAULT_DEMDEX_VERSION = '3.3.0';
var TIME_BETWEEN_RETRIES = 15;
var TIMES_TO_RETRY = 80;
var TRACKING_SERVER = 'schibstedspain.d3.sc.omtrdc.net';
var SERVERS = {
  trackingServer: TRACKING_SERVER,
  trackingServerSecure: TRACKING_SERVER
};
var mcvid;

var syncMail = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(demdex) {
    var hashedUserEmail, userEmail;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            // 1. We try to get the hashed user email from the segment wrapper config
            hashedUserEmail = getConfig('hashedUserEmail'); // 2. If not available, we try to get the userEmail from config and hash it
            // we dynamically import the module of hashing to avoid bloating the bundle
            // if not needed

            if (hashedUserEmail) {
              _context.next = 7;
              break;
            }

            userEmail = getConfig('userEmail');

            if (!userEmail) {
              _context.next = 7;
              break;
            }

            _context.next = 6;
            return import('./hashEmail.js').then(function (_ref2) {
              var hashEmail = _ref2.hashEmail;
              return hashEmail(userEmail);
            });

          case 6:
            hashedUserEmail = _context.sent;

          case 7:
            // 3. if we have at this point a hashed email, then we sync with Demdex
            if (hashedUserEmail) {
              demdex.setCustomerIDs({
                hashed_email: {
                  id: hashedUserEmail,
                  authState: AUTHENTICATE_STATE
                }
              });
            }

          case 8:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function syncMail(_x) {
    return _ref.apply(this, arguments);
  };
}();

var getDemdex = function getDemdex() {
  return window.Visitor && window.Visitor.getInstance(ADOBE_ORG_ID, SERVERS);
};

var getMarketingCloudVisitorID = function getMarketingCloudVisitorID(demdex) {
  var mcvid = demdex && demdex.getMarketingCloudVisitorID();
  syncMail(demdex);
  return mcvid;
};

var getAdobeVisitorData = function getAdobeVisitorData() {
  var demdex = getDemdex() || {};
  var _demdex$version = demdex.version,
      version = _demdex$version === void 0 ? DEFAULT_DEMDEX_VERSION : _demdex$version;
  var trackingServer = SERVERS.trackingServer;
  return Promise.resolve({
    trackingServer: trackingServer,
    version: version
  });
};

export var getAdobeMarketingCloudVisitorIdFromWindow = function getAdobeMarketingCloudVisitorIdFromWindow() {
  if (mcvid) return Promise.resolve(mcvid);
  return new Promise(function (resolve) {
    function retry(retries) {
      if (retries === 0) return resolve('');
      var demdex = getDemdex();
      mcvid = getMarketingCloudVisitorID(demdex);
      return mcvid ? resolve(mcvid) : window.setTimeout(function () {
        return retry(--retries);
      }, TIME_BETWEEN_RETRIES);
    }

    retry(TIMES_TO_RETRY);
  });
};

var importVisitorApiAndGetAdobeMCVisitorID = function importVisitorApiAndGetAdobeMCVisitorID() {
  return import('./adobeVisitorApi.js').then(function () {
    mcvid = getAdobeMarketingCloudVisitorIdFromWindow();
    return mcvid;
  });
};

var getAdobeMCVisitorID = function getAdobeMCVisitorID() {
  var getCustomAdobeVisitorId = getConfig('getCustomAdobeVisitorId');

  if (typeof getCustomAdobeVisitorId === 'function') {
    return getCustomAdobeVisitorId();
  }

  return getConfig('importAdobeVisitorId') === true ? importVisitorApiAndGetAdobeMCVisitorID() : getAdobeMarketingCloudVisitorIdFromWindow();
};

export { getAdobeVisitorData, getAdobeMCVisitorID };

==> segment-wrapper-3.7.0.tgz: package/lib/adobeRepository.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import { getConfig } from './config.js';
import { getUniversalIdAndNotify } from './universalId.js';
var ADOBE_ORG_ID = '05FF6243578784B37F000101@AdobeOrg';
var AUTHENTICATE_STATE = 1;
var DEFAULT_DEMDEX_VERSION = '3.3.0';
var TIME_BETWEEN_RETRIES = 15;
var TIMES_TO_RETRY = 80;
var TRACKING_SERVER = 'schibstedspain.d3.sc.omtrdc.net';
var SERVERS = {
  trackingServer: TRACKING_SERVER,
  trackingServerSecure: TRACKING_SERVER
};
var mcvid;

var syncMail = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(demdex) {
    var universalId;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return getUniversalIdAndNotify();

          case 2:
            _context.t0 = _context.sent;

            if (_context.t0) {
              _context.next = 5;
              break;
            }

            _context.t0 = getConfig('hashedUserEmail');

          case 5:
            universalId = _context.t0;

            if (universalId) {
              demdex.setCustomerIDs({
                hashed_email: {
                  id: universalId,
                  authState: AUTHENTICATE_STATE
                }
              });
            }

          case 7:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function syncMail(_x) {
    return _ref.apply(this, arguments);
  };
}();

var getDemdex = function getDemdex() {
  return window.Visitor && window.Visitor.getInstance(ADOBE_ORG_ID, SERVERS);
};

var getMarketingCloudVisitorID = function getMarketingCloudVisitorID(demdex) {
  var mcvid = demdex && demdex.getMarketingCloudVisitorID();
  syncMail(demdex);
  return mcvid;
};

var getAdobeVisitorData = function getAdobeVisitorData() {
  var demdex = getDemdex() || {};
  var _demdex$version = demdex.version,
      version = _demdex$version === void 0 ? DEFAULT_DEMDEX_VERSION : _demdex$version;
  var trackingServer = SERVERS.trackingServer;
  return Promise.resolve({
    trackingServer: trackingServer,
    version: version
  });
};

export var getAdobeMarketingCloudVisitorIdFromWindow = function getAdobeMarketingCloudVisitorIdFromWindow() {
  if (mcvid) return Promise.resolve(mcvid);
  return new Promise(function (resolve) {
    function retry(retries) {
      if (retries === 0) return resolve('');
      var demdex = getDemdex();
      mcvid = getMarketingCloudVisitorID(demdex);
      return mcvid ? resolve(mcvid) : window.setTimeout(function () {
        return retry(--retries);
      }, TIME_BETWEEN_RETRIES);
    }

    retry(TIMES_TO_RETRY);
  });
};

var importVisitorApiAndGetAdobeMCVisitorID = function importVisitorApiAndGetAdobeMCVisitorID() {
  return import('./adobeVisitorApi.js').then(function () {
    mcvid = getAdobeMarketingCloudVisitorIdFromWindow();
    return mcvid;
  });
};

var getAdobeMCVisitorID = function getAdobeMCVisitorID() {
  var getCustomAdobeVisitorId = getConfig('getCustomAdobeVisitorId');

  if (typeof getCustomAdobeVisitorId === 'function') {
    return getCustomAdobeVisitorId();
  }

  return getConfig('importAdobeVisitorId') === true ? importVisitorApiAndGetAdobeMCVisitorID() : getAdobeMarketingCloudVisitorIdFromWindow();
};

export { getAdobeVisitorData, getAdobeMCVisitorID };
